@@ -1149,6 +1149,19 @@ def test_nested_functions(nested):
     isvalue(interp, 'o1', 3.5)
     isvalue(interp, 'o2', 1.5)
 
+@pytest.mark.parametrize("nested", [False, True])
+def test_lambda(nested):
+    """test using lambda definitions"""
+    interp = make_interpreter(nested_symtable=nested)
+
+    interp(textwrap.dedent("""
+    my_func = lambda x: 2 + 3*x
+    out = my_func(3)
+    """))
+    assert len(interp.error) == 0
+    isvalue(interp, 'out', 11.0)
+
+
 @pytest.mark.parametrize("nested", [False, True])
 def test_astdump(nested):
     """test ast parsing and dumping"""
@@ -1231,7 +1244,7 @@ def test_kaboom(nested):
     interp("""(lambda fc=(lambda n: [c for c in ().__class__.__bases__[0].__subclasses__() if c.__name__ == n][0]):
     fc("function")(fc("code")(0,0,0,0,"KABOOM",(),(),(),"","",0,""),{})()
 )()""")
-    check_error(interp, 'NotImplementedError')  # Safe, lambda is not supported
+    check_error(interp, 'AttributeError')  # Safe, unassigned lambda is not supported
 
     interp("""[print(c) for c in ().__class__.__bases__[0].__subclasses__()]""")  # Try a portion of the kaboom...
 
@@ -1689,5 +1702,41 @@ def test_augassign_lineno(nested):
     check_error(interp, 'ZeroDivisionError', 'x /= 0')
     assert interp.error[0].lineno == 3
 
+@pytest.mark.parametrize("nested", [False, True])
+def test_unreachable_statement_while_loop(nested):
+    """unreachable statement inside while loop"""
+
+    interp = make_interpreter(nested_symtable=nested)
+    interp("""
+def f():
+    return "ok"
+
+x_before = 0
+x_after = 0
+while True:
+    x_before += 1
+    _ = f()
+    x_after += 1
+    if x_after >= 10:
+        break
+
+result = (x_before, x_after)
+
+xa = xb = 0
+for i in range(4):
+    xb += 1
+    _ = f()
+    xa += 1
+result2 = (xb, xa)
+
+""")
+
+    (x, y) = interp("result")
+    assert x == 10
+    assert y == 10
+    (x, y) = interp("result2")
+    assert x == 4
+    assert y == 4
+
 if __name__ == '__main__':
     pytest.main(['-v', '-x', '-s'])
